CrouchPillowQuestionRoomCompanion class

Constructors

CrouchPillowQuestionRoomCompanion({Value<int> retailerNurseryInquiryId = const i0.Value.absent(), Value<int> plannedSpecificCreateUser = const i0.Value.absent(), Value<String> chaseThroughEffectTitle = const i0.Value.absent(), Value<String> stomachGooseClawsDesc = const i0.Value.absent()})
const
CrouchPillowQuestionRoomCompanion.insert({Value<int> retailerNurseryInquiryId = const i0.Value.absent(), required int plannedSpecificCreateUser, required String chaseThroughEffectTitle, required String stomachGooseClawsDesc})

Properties

chaseThroughEffectTitle → Value<String>
final
hashCode int
The hash code for this object.
no setterinherited
plannedSpecificCreateUser → Value<int>
final
retailerNurseryInquiryId → Value<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stomachGooseClawsDesc → Value<String>
final

Methods

copyWith({Value<int>? retailerNurseryInquiryId, Value<int>? plannedSpecificCreateUser, Value<String>? chaseThroughEffectTitle, Value<String>? stomachGooseClawsDesc}) CrouchPillowQuestionRoomCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<int>? retailerNurseryInquiryId, Expression<int>? plannedSpecificCreateUser, Expression<String>? chaseThroughEffectTitle, Expression<String>? stomachGooseClawsDesc}) → Insertable<CrouchPillowQuestionRoomEntity>