CrouchPillowQuestionRoomEntity class
Constructors
- CrouchPillowQuestionRoomEntity({required int retailerNurseryInquiryId, required int plannedSpecificCreateUser, required String chaseThroughEffectTitle, required String stomachGooseClawsDesc})
-
const
-
CrouchPillowQuestionRoomEntity.fromJson(Map<
String, dynamic> json, {ValueSerializer? serializer}) -
factory
Properties
- chaseThroughEffectTitle → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- plannedSpecificCreateUser → int
-
final
- retailerNurseryInquiryId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stomachGooseClawsDesc → String
-
final
Methods
-
copyWith(
{int? retailerNurseryInquiryId, int? plannedSpecificCreateUser, String? chaseThroughEffectTitle, String? stomachGooseClawsDesc}) → CrouchPillowQuestionRoomEntity -
copyWithCompanion(
CrouchPillowQuestionRoomCompanion data) → CrouchPillowQuestionRoomEntity -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(
bool nullToAbsent) → Map< String, Expression< Object> > - Converts this object into a map of column names to expressions to insert or update.
-
toCompanion(
bool nullToAbsent) → CrouchPillowQuestionRoomCompanion -
toJson(
{ValueSerializer? serializer}) → Map< String, dynamic> -
Converts this object into a representation that can be encoded with
json. Theserializercan be used to configure how individual values will be encoded. By default,DriftRuntimeOptions.defaultSerializerwill be used. SeeValueSerializer.defaultsfor details. -
toJsonString(
{ValueSerializer? serializer}) → String -
Converts this object into a json representation. The
serializercan be used to configure how individual values will be encoded. By default,DriftRuntimeOptions.defaultSerializerwill be used. SeeValueSerializer.defaultsfor details.inherited -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override